@@ -34,6 +34,15 @@ FAKE_KEY = os.path.join(TEST_DIR, "fake-key-file")
 FAKE_CA = os.path.join(TEST_DIR, "fake-ca-file")
 
 
+def test_deprecation_warning():
+    with pytest.deprecated_call():
+        from dask_kubernetes import KubeCluster as TLKubeCluster
+
+    from dask_kubernetes.classic import KubeCluster as ClassicKubeCluster
+
+    assert TLKubeCluster is ClassicKubeCluster
+
+
 @pytest.fixture
 def pod_spec(docker_image):
     yield clean_pod_template(
